mod url_shortener;
mod database_adapter;
mod redis_adapter;

use std::net::SocketAddr;

use ini::ini;
use axum::{routing::get, Router, response::Html};

#[tokio::main]
async fn main() {
    let config = ini!("config.ini");
    let server_address = match &config["database"]["server"] {
        Some(adr) => adr,
        None => panic!("Could not find [database]/server in config")
    };
    let web_bind_address = match &config["web_server"]["bind_address"] {
        Some(adr) => adr,
        None => panic!("Could not find [web_server]/bind_address in config")
    };
    
    let app = Router::new()
        .route("/", get(root))
        .route("/test", get(get_test).post(post_test));

    let addr: SocketAddr = web_bind_address.parse().expect("Unable to parse [web_server]/bind_address in config");

    dbg!(addr);

    axum::Server::bind(&addr)
        .serve(app.into_make_service())
        .await
        .unwrap();

}

async fn root() -> Html<&'static str> {
    Html("root<br>
    <a href=\"/test\">test</a>
    <br>
    <form action=\"test\" method=\"post\">
        <input type=\"submit\" />
    </form>
    ")
    
}

async fn get_test() -> &'static str {
    "get_test"
}

async fn post_test() -> &'static str {
    "post_test"
}